==> fet_3.12.30.orig.tar.gz: fet-3.12.30/src/interface/addconstraintroomnotavailableform.h <==
/***************************************************************************
                          addconstraintroomnotavailableform.h  -  description
                             -------------------
    begin                : January 8, 2004
    copyright            : (C) 2004 by Lalescu Liviu
    email                : liviu@lalescu.ro
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTROOMNOTAVAILABLEFORM_H
#define ADDCONSTRAINTROOMNOTAVAILABLEFORM_H

#include "addconstraintroomnotavailableform_template.h"
#include "genetictimetable_defs.h"
#include "genetictimetable.h"
#include "fet.h"
#include "fetmainform.h"

#include <qcombobox.h>
#include <qmessagebox.h>
#include <qgroupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qtextedit.h>

class AddConstraintRoomNotAvailableForm : public AddConstraintRoomNotAvailableForm_template  {
public:
	AddConstraintRoomNotAvailableForm();
	~AddConstraintRoomNotAvailableForm();
	
	void updateRoomsComboBox();

	void addConstraint();
};

#endif

==> fet_5.4.10.orig.tar.gz: fet-5.4.10/src/interface/addconstraintroomnotavailableform.h <==
/***************************************************************************
                          addconstraintroomnotavailableform.h  -  description
                             -------------------
    begin                : January 8, 2004
    copyright            : (C) 2004 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTROOMNOTAVAILABLEFORM_H
#define ADDCONSTRAINTROOMNOTAVAILABLEFORM_H

#include "addconstraintroomnotavailableform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"
//#include "fetmainform.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class AddConstraintRoomNotAvailableForm : public AddConstraintRoomNotAvailableForm_template  {
public:
	AddConstraintRoomNotAvailableForm();
	~AddConstraintRoomNotAvailableForm();
	
	void updateRoomsComboBox();

	void addConstraint();
};

#endif
